@@ -262,11 +262,8 @@ def django_to_cache(
             cache_conf,
     ):
         filter_by = cache_conf['filter_by']
-        if filter_by.keys():
-            if django_model in filter_by.keys():
-                django_instances = await django_sync_to_async_list(django_model.objects.filter, filter_by[django_model])
-            else:
-                django_instances = await django_sync_to_async_list(django_model.objects.all)
+        if filter_by:
+            django_instances = await django_sync_to_async_list(django_model.objects.filter, filter_by)
         else:
             django_instances = await django_sync_to_async_list(django_model.objects.all)
         async_chunk_size = redis_root.async_db_requests_limit
@@ -403,14 +400,13 @@ async def django_instance_to_redis_params(
         cache_conf,
 ):
     redis_params = {}
-    django_model = django_instance.__class__
     exclude_fields = cache_conf['exclude_fields']
     for i, django_field in enumerate(django_instance.__class__._meta.get_fields()):
         if not django_field.__class__.__name__.endswith('Rel'):
             django_field_name = django_field.name
             allowed = True
-            if django_model in exclude_fields.keys():
-                allowed = (django_field_name not in exclude_fields[django_model])
+            if exclude_fields:
+                allowed = (django_field.name not in exclude_fields)
             if allowed:
                 if django_field.name not in ['id', 'pk']:
                     redis_param = await django_instance_field_to_redis_value(
