@@ -451,8 +451,8 @@ class RedisRoot:
             for django_field in django_model._meta.get_fields():
                 django_field_name = django_field.name
                 allowed = True
-                if django_model in exclude_fields.keys():
-                    allowed = (django_field_name not in exclude_fields[django_model])
+                if exclude_fields:
+                    allowed = (django_field.name not in exclude_fields)
                 if allowed:
                     if django_field.name in ['id', 'pk']:
                         django_field_name = 'django_id'
@@ -536,8 +536,7 @@ class RedisRoot:
                         if value is not None:
                             value = value.model
                             if value is not None:
-                                value = get_or_create_redis_model_from_django_model(value, redis_root,
-                                                                                    save_related_models, exclude_fields)
+                                value = redis_root.get_or_create_redis_model_from_django_model(value)
                                 if value is not None:
                                     allowed_redis_params[redis_field_param_name] = value
                                     allowed_redis_params['save_related_models'] = save_related_models
@@ -560,6 +559,7 @@ class RedisRoot:
         save_related_models = cache_conf['save_related_models']
         exclude_fields = cache_conf['exclude_fields']
 
+
         redis_fields = django_fields_to_redis_fields(django_model, self, save_related_models, exclude_fields)
         registered_models_names = [model.__name__ for model in self.registered_models]
         if django_model.__name__ in registered_models_names:
@@ -573,17 +573,8 @@ class RedisRoot:
 
     def check_cache(self):
         django_models_to_cache = self._get_django_models_to_cache()
-        exclude_fields = {
-            django_model: cache_conf['exclude_fields']
-            for django_model, cache_conf in django_models_to_cache.items()
-        }
-        filter_by = {
-            django_model: cache_conf['filter_by']
-            for django_model, cache_conf in django_models_to_cache.items()
-        }
         for django_model, cache_conf in django_models_to_cache.items():
             cache_func = cache_conf['cache_func']
-            save_related_models = cache_conf['save_related_models']
 
             redis_model = self.get_or_create_redis_model_from_django_model(django_model)
 
